# Page Deletion Guard
This module locks and prevents certain nodes/pages from being deleted via the UI and access control handler access method regardless of permission or role (even admin). This will be useful for safe guarding important or valuable pages that should never be deleted under any circumstance. Especially helpful for pages created in layout builder that would be tedious or difficult to duplicate. Locked nodes will also be identifiable in the content overview page by the '🔒' symbol to the right of the title.

## Table of contents
* Requirements
* Installation
* Configuration
* Developing

## Requirements
This module requires no modules outside of Drupal core.

## Installation
Install as you would normally install a contributed Drupal module. For further information, see [Installing Drupal Modules]([url](https://www.drupal.org/docs/extending-drupal/installing-modules)).

## Configuration and usage
1. Enable the module by navigating to <b>Administration > Extend</b>.
2. Navigate to <b>admin/content/lock-pages</b> and search for node/page you want to lock.
3. From the same lock page, you can uncheck locked pages to allow for them to be deleted.

## Developing
To assist with local development and testing, there is a Dockerfile that can be used. All module dependencies are included.

```shell
docker-compose up -d --build
```

### Enabling Xdebug for Debugging

```shell
XDEBUG_MODE=debug docker-compose up
```

### Running Drush Commands

```shell
docker-compose exec drupal drush cr
```

### Running Drupal PHPUnit Tests

```shell
docker-compose exec drupal phpunit
```

### Running Drupal Code Quality Tests

```shell
docker-compose exec drupal phpcs
```

### Running Drupal Code Beautifier and Fixer

```shell
docker-compose exec drupal phpcbf
```
